Poročila | OiRA

Teme

# Poročila

Poročilo lahko uporabite za:

- predložitev dokazov nadzornim organom;
- seznanitev zadevnih oseb (delavcev, predstavnikov za varnost, delodajalcev, strokovnjakov na področju varnosti in zdravja pri delu itd.) z informacijami;
- spremljanje in ocenjevanje, ali so bili uvedeni potrebni ukrepi;
- evidentiranje popravkov v primeru sprememb okoliščin (novi stroji/delavci, na podlagi ugotovitev iz morebitnih preiskav nesreč itd.).

Poročilo lahko shranite v svoj računalnik in ga natisnete. Lahko ga tudi spremenite ali dodate nove informacije. Upoštevajte, da se morebitne spremembe, ki jih naredite v prenesenem poročilu, NE shranijo v orodju OiRA.

## Razpoložljiva poročila

Na voljo so različna poročila za različne namene. Sklop poročil, ki je na voljo za specifična orodja, je odvisen od odločitev nacionalnih partnerjev/razvijalcev orodja OiRA.

Razpoložljiva poročila.

### Celovito poročilo

Oblika zapisa: Word/Office Open XML (.docx). Po prenosu lahko poročilo urejate.

Vključuje: vse informacije in vhodne podatke, ki ste jih vnesli med postopkom ocenjevanja tveganj.

Uporabite ga lahko za: predložitev dokazov o oceni tveganja nadzornim organom (npr. inšpektoratu za delo).

### Načrt ukrepov

Oblika zapisa: Excel/Office Open XML (.xlsx). Po prenosu lahko načrt ukrepov urejate.

Vključuje: informacije o vseh ukrepih, ki ste se jih odločili izvesti.

Uporabite ga lahko za:

- dejavno spremljanje izvajanja izbranih ukrepov;
- upravljanje težav/tveganj na svojem delovnem mestu (posebnih nalog, strokovnega znanja, odgovornosti, rokov).

### Pregled tveganj

Oblika zapisa: prenosna oblika dokumenta (.pdf). Po prenosu pregleda tveganj ne morete urejati.

Vključuje: pregled opredeljenih tveganj.

Uporabite ga lahko za:

- hiter pregled statusa tveganj na svojem delovnem mestu;
- seznanitev zadevnih ljudi z informacijami;
- spremljanje, ali se tveganja/ukrepi ustrezno obravnavajo.

### Pregled ukrepov

Oblika zapisa: prenosna oblika dokumenta (.pdf). Po prenosu pregleda tveganj ne morete urejati.

Vključuje: hiter pregled ukrepov, ki jih je treba izvesti.

Uporabite ga lahko za:

- pridobitev hitrega pregleda status ukrepov, ki ste se jih odločili izvesti;
- seznanitev zadevnih ljudi z informacijami;
- spremljanje, ali se tveganja/ukrepi ustrezno obravnavajo.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More